Index: content/public/browser/speech_recognition_session_context.h |
diff --git a/content/public/browser/speech_recognition_session_context.h b/content/public/browser/speech_recognition_session_context.h |
index 94931894e68ed6dca5fcf4ec9a00dd0301bd1e18..00a1d06d459fe543004603c87298d2d0ff1db43d 100644 |
--- a/content/public/browser/speech_recognition_session_context.h |
+++ b/content/public/browser/speech_recognition_session_context.h |
@@ -25,25 +25,24 @@ struct CONTENT_EXPORT SpeechRecognitionSessionContext { |
~SpeechRecognitionSessionContext(); |
int render_process_id; |
- int render_view_id; |
int render_frame_id; |
// Browser plugin guest's render view id, if this context represents a speech |
// recognition request from an embedder on behalf of the guest. This is used |
// for input tag where speech bubble is to be shown. |
// |
// TODO(lazyboy): Right now showing bubble from guest does not work, we fall |
// back to embedder instead, fix this and use |
// embedder_render_process_id/embedder_render_view_id similar to Web Speech |
// API below. |
- int guest_render_view_id; |
+ int guest_render_frame_id; |
- // The pair (|embedder_render_process_id|, |embedder_render_view_id|) |
+ // The pair (|embedder_render_process_id|, |embedder_render_frame_id|) |
// represents a Browser plugin guest's embedder. This is filled in if the |
// session is from a guest Web Speech API. We use these to check if the |
// embedder (app) is permitted to use audio. |
int embedder_render_process_id; |
- int embedder_render_view_id; |
+ int embedder_render_frame_id; |
int request_id; |
@@ -25,25 +25,24 @@ struct CONTENT_EXPORT SpeechRecognitionSessionContext { |
int render_frame_id; |
- // Browser plugin guest's render view id, if this context represents a speech |
+ // Browser plugin guest's render frame id, if this context represents a speech |
// recognition request from an embedder on behalf of the guest. This is used |
// for input tag where speech bubble is to be shown. |
@@ -25,25 +25,24 @@ struct CONTENT_EXPORT SpeechRecognitionSessionContext { |
// TODO(lazyboy): Right now showing bubble from guest does not work, we fall |
// back to embedder instead, fix this and use |
- // embedder_render_process_id/embedder_render_view_id similar to Web Speech |
+ // embedder_render_process_id/embedder_render_frame_id similar to Web Speech |
// API below. |